Jennifer Lawrence Shows Up At The Louisville-Kentucky Game | The Daily Caller
Description: The Louisville Cardinals hosted the Kentucky Wildcats on Saturday for one of the 2014 season's most highly anticipated college basketball games. Rick Pitino's 4th ranked Cardinals have had a great
Keywords: college basketball,jennifer lawrence,john calipari,rick pitino,university of kentucky,university of louisville

Sports
Dec 27, 2014; Louisville, KY, USA; Louisville Cardinals forward Montrezl Harrell (24) posts up against Kentucky Wildcats guard Aaron Harrison (2) during the first half at KFC Yum! Center. Mandatory Credit: Jamie Rhodes-USA TODAY Sports - RTR4JDW4

# Jennifer Lawrence Made An Appearance At The Louisville-Kentucky Flop Fest [VIDEO]

4:44 PM 12/27/2014
Pinterest
Reddit
LinkedIn
Christian Datoc
Sports Editor

- See All Articles
- Send Email
- Subscribe to RSS

- Tweet

4419915

The Louisville Cardinals hosted the Kentucky Wildcats on Saturday for one of the 2014 season’s most highly anticipated college basketball games.

Rick Pitino’s 4th ranked Cardinals have had a great start to the season, but they were still huge underdogs against John Calipari’s unbeaten powerhouse. (RELATED: Kentucky Basketball’s Christmas Card Must Be Pretty Intimidating For Opposing Teams)

Louisville trailed by 4 points at halftime, but they couldn’t close the gap thanks to plays like this.

WATCH:

Slow it down one time.

What a joke.

In games like these, I usually cheer for the underdog, but that flop had me wanting Kentucky to win by fifty. (RELATED: Forget ISIS, China And Immigrants; Flopping Is Threatening To Destroy America)

Like the rest of their games this season, the Wildcats eventually pulled away from their cross-state rival. UK won by a final score of 58-50.

On a side note, apparently Jennifer Lawrence is a Cardinals fan.

> NEW: Jennifer Lawrence at the Louisville Cardinals basketball game today (Dec. 27) pic.twitter.com/soxnfJGWwd

> — Jennifer Lawrence (@JenniferUpdates) December 27, 2014

> "May the odds be ever in Louisville's favor!" – Jennifer Lawrence http://t.co/rE6Li6QWGp pic.twitter.com/zK8QMCzPDf

> — Sporting News (@sportingnews) December 27, 2014

I love you too, J. Law.

Follow Datoc on Twitter

Tags: College basketball, Jennifer Lawrence, John Calipari, Rick Pitino, University of Kentucky, University of Louisville
Share
TOP
Leave a Comment
Top